@@ -30,6 +30,7 @@ use OCA\Bookmarks\Controller\Rest\InternalFoldersController;
 use OCA\Bookmarks\Controller\Rest\PublicController;
 use OCA\Bookmarks\Controller\Rest\SettingsController;
 use OCP\IUser;
+use OCP\IURLGenerator;
 
 class Application extends App {
 	public function __construct(array $urlParams = []) {
@@ -69,7 +70,8 @@ class Application extends App {
 				$c->query('ServerContainer')->getL10NFactory()->get('bookmarks'),
 				$c->query('ServerContainer')->query(Bookmarks::class),
 				$c->query('ServerContainer')->getUserManager(),
-				$c->query('ServerContainer')->getLogger()
+				$c->query('ServerContainer')->getLogger(),
+				$c->query('ServerContainer')->getUserSession()
 			);
 		});
 
@@ -90,7 +92,9 @@ class Application extends App {
 				$c->query('ServerContainer')->query(FaviconPreviewService::class),
 				$c->query('ServerContainer')->query(ScreenlyPreviewService::class),
 				$c->query('ServerContainer')->query(ITimeFactory::class),
-				$c->query('ServerContainer')->getLogger()
+				$c->query('ServerContainer')->getLogger(),
+				$c->query('ServerContainer')->getUserSession(),
+				$c->query('ServerContainer')->query(IURLGenerator::class)
 			);
 		});
 
