@@ -433,7 +433,7 @@ class Bookmarks {
 
 	/**
 	 * @brief Finds all bookmarks, matching the filter
-	 * @param string $userid UserId
+	 * @param string $userid UserId pass -1 to not restrict bookmarks to one user
 	 * @param int $offset offset
 	 * @param string $sqlSortColumn result with this column
 	 * @param string|array $filters filters can be: empty -> no filter, a string -> filter this, a string array -> filter for all strings
@@ -506,9 +506,12 @@ class Bookmarks {
 			->from('bookmarks', 'b')
 			->leftJoin('b', 'bookmarks_tags', 't', $qb->expr()->eq('t.bookmark_id', 'b.id'))
 			->leftJoin('b', 'bookmarks_folders_bookmarks', 'f', $qb->expr()->eq('f.bookmark_id', 'b.id'))
-			->where($qb->expr()->eq('user_id', $qb->createPositionalParameter($userid)))
 			->groupBy(array_merge($selectedAttributes, [$sqlSortColumn]));
 
+		if ($userid !== -1) {
+			$qb->where($qb->expr()->eq('user_id', $qb->createPositionalParameter($userid)));
+		}
+
 		if (isset($parentFolder)) {
 			$qb->andWhere($qb->expr()->eq('f.folder_id', $qb->createPositionalParameter($parentFolder)));
 		}
@@ -916,7 +919,7 @@ class Bookmarks {
 					'title' => $qb->createParameter('title'),
 					'user_id' => $qb->createParameter('user_id'),
 					'public' => $qb->createParameter('public'),
-					'added' => isset($date_added) ? $date_added : $qb->createFunction('UNIX_TIMESTAMP()'),
+					'added' => isset($date_added)? $date_added : $qb->createFunction('UNIX_TIMESTAMP()'),
 					'lastmodified' => $qb->createFunction('UNIX_TIMESTAMP()'),
 					'description' => $qb->createParameter('description'),
 				])
@@ -1122,7 +1125,7 @@ class Bookmarks {
 		$folderId = $this->addFolder($userId, $folder['title'], $parentId);
 		foreach ($folder['bookmarks'] as $bookmark) {
 			try {
-				$this->addBookmark($userId, $bookmark['href'], $bookmark['title'], $bookmark['tags'], $bookmark['description'], false, [$folderId], $bookmark['add_date']);
+				$this->addBookmark($userId, $bookmark['href'], $bookmark['title'], $bookmark['tags'], $bookmark['description'], false, [$folderId], $bookmark['add_date']->getTimestamp());
 			} catch (\InvalidArgumentException $e) {
 				$this->logger->logException($e, ['app' => 'bookmarks']);
 				$errors[] =  $this->l->t('Failed to import one bookmark, because: ') . $e->getMessage();
