@@ -13,10 +13,13 @@ namespace OCA\Bookmarks\Controller\Rest;
 use OCP\IDBConnection;
 use OCP\IL10N;
 use OCP\ILogger;
+use OCP\IUserSession;
 use \OCP\IRequest;
+use \OCP\IURLGenerator;
 use \OCP\AppFramework\ApiController;
 use \OCP\AppFramework\Http\DataDisplayResponse;
 use \OCP\AppFramework\Http\NotFoundResponse;
+use \OCP\AppFramework\Http\RedirectResponse;
 use \OCP\AppFramework\Http\JSONResponse;
 use \OCP\AppFramework\Http;
 use \OC\User\Manager;
@@ -49,16 +52,19 @@ class InternalBookmarkController extends ApiController {
 		IPreviewService $faviconService,
 		IPreviewService $screenshotService,
 		ITimeFactory $timeFactory,
-		ILogger $logger
+		ILogger $logger,
+		IUserSession $userSession,
+		IURLGenerator $url
 	) {
 		parent::__construct($appName, $request);
-		$this->publicController = new BookmarkController($appName, $request, $userId, $db, $l10n, $bookmarks, $userManager, $logger);
+		$this->publicController = new BookmarkController($appName, $request, $userId, $db, $l10n, $bookmarks, $userManager, $logger, $userSession);
 		$this->userId = $userId;
 		$this->libBookmarks = $bookmarks;
 		$this->previewService = $previewService;
 		$this->faviconService = $faviconService;
 		$this->screenshotService = $screenshotService;
 		$this->timeFactory = $timeFactory;
+		$this->url = $url;
 	}
 
 	/**
@@ -245,7 +251,8 @@ class InternalBookmarkController extends ApiController {
 		$bookmark = $this->libBookmarks->findUniqueBookmark($id, $this->userId);
 		$image = $this->faviconService->getImage($bookmark);
 		if (!isset($image)) {
-			return new NotFoundResponse();
+			// Return a placeholder
+			return new RedirectResponse($this->url->getAbsoluteURL('/svg/core/places/link?color=666666'));
 		}
 		return $this->doImageResponse($image);
 	}
