@@ -28,19 +28,21 @@ class InternalTagsController extends ApiController {
 	/**
 	 * @param string $old_name
 	 * @param string $new_name
+	 * @param string $name
 	 * @return JSONResponse
 	 *
 	 * @NoAdminRequired
 	 */
-	public function renameTag($old_name = "", $new_name = "") {
-		return $this->publicController->renameTag($old_name, $new_name);
+	public function renameTag($old_name = "", $new_name = "", $name = '') {
+		return $this->publicController->renameTag($old_name, $new_name, $name);
 	}
 
 	/**
+	 * @param bool $count whether to add the count of bookmarks per tag
 	 * @NoAdminRequired
 	 */
-	public function fullTags() {
-		return $this->publicController->fullTags();
+	public function fullTags($count) {
+		return $this->publicController->fullTags($count);
 	}
 
 }
