@@ -8,12 +8,10 @@ use \OCP\AppFramework\Http;
 use \OCP\AppFramework\Http\JSONResponse;
 use \OC\User\Manager;
 use OCA\Bookmarks\Controller\Lib\Bookmarks;
-use OCP\Util;
 
 class PublicController extends ApiController {
-
 	private $userManager;
-	
+
 	private $userId;
 
 	/** @var Bookmarks */
@@ -26,7 +24,7 @@ class PublicController extends ApiController {
 		$this->userManager = $userManager;
 		$this->userId = $userId;
 	}
-	
+
 	/**
 	 * @param string $user
 	 * @param string $password
@@ -41,45 +39,42 @@ class PublicController extends ApiController {
 	 * @NoCSRFRequired
 	 * @PublicPage
 	 */
-	public function returnAsJson($user, $password = null, $tags = array(), $conjunction = "or", $select = null, $sortby = "") {
-
-		if ($user == null || $this->userManager->userExists($user) == false) {
+	public function returnAsJson($user, $password = null, $tags = [], $conjunction = "or", $select = null, $sortby = "") {
+		if ($user === null || $this->userManager->userExists($user) === false) {
 			return $this->newJsonErrorMessage("User could not be identified");
 		}
 
 		if (!is_array($tags)) {
-			if(is_string($tags) && $tags !== '') {
+			if (is_string($tags) && $tags !== '') {
 				$tags = [ $tags ];
 			} else {
-				$tags = array();
+				$tags = [];
 			}
 		}
 
 		$public = true;
 
-		if ($password != null) {
+		if ($password !== null) {
 			$public = false;
 		}
 
 
 		if (!$public && !$this->userManager->checkPassword($user, $password)) {
-
 			$msg = 'REST API accessed with wrong password';
-			Util::writeLog('bookmarks', $msg, Util::WARN);
 
 			return $this->newJsonErrorMessage("Wrong password for user " . $user);
 		}
 
-		$attributesToSelect = array('url', 'title');
+		$attributesToSelect = ['url', 'title'];
 
-		if ($select != null) {
+		if ($select !== null) {
 			$attributesToSelect = array_merge($attributesToSelect, $select);
 			$attributesToSelect = array_unique($attributesToSelect);
 		}
 
 		$output = $this->bookmarks->findBookmarks($user, 0, $sortby, $tags, true, -1, $public, $attributesToSelect, $conjunction);
 
-		if (count($output) == 0) {
+		if (count($output) === 0) {
 			$output["status"] = 'error';
 			$output["message"] = "No results from this query";
 			return new JSONResponse($output);
@@ -93,7 +88,7 @@ class PublicController extends ApiController {
 	 * @return JSONResponse
 	 */
 	public function newJsonErrorMessage($message) {
-		$output = array();
+		$output = [];
 		$output["status"] = 'error';
 		$output["message"] = $message;
 		return new JSONResponse($output);
