@@ -6,6 +6,7 @@ OC.L10N.register(
     "No file provided for import" : "Δεν δόθηκε αρχείο για εισαγωγή",
     "Unsupported file type for import" : "Μη υποστηριζόμενος τύπος αρχείου",
     "Add a Bookmark" : "Προσθήκη σελιδοδείκτη",
+    "Add folder" : "Προσθήκη φακέλου",
     "Select" : "Επιλογή",
     "Deselect" : "Αποεπιλογή",
     "Details" : "Λεπτομέρειες",
@@ -14,6 +15,7 @@ OC.L10N.register(
     "Tags" : "Ετικέτες",
     "Description" : "Περιγραφή",
     "No bookmarks here." : "Δεν υπάρχουν σελιδοδείκτες εδώ",
+    "Favorites" : "Αγαπημένα",
     "Settings" : "Ρυθμίσεις",
     "Add to {instanceName} " : "Προσθήκη στο {instanceName} ",
     "Recently added" : "Προστέθηκαν πρόσφατα",
@@ -21,6 +23,7 @@ OC.L10N.register(
     "Open details" : "Άνοιγμα λεπτομερειών",
     "An error occurred while trying to save the bookmark." : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση του σελιδοδείκτη",
     "Error" : "Σφάλμα",
+    "Uncategorized" : "Μή-κατηγοριοποιημένα",
     "Set tags" : "Ορισμός ετικετών",
     "Add a bookmark" : "Προσθήκη σελιδοδείκτη",
     "The title of the page" : "Ο τίτλος της σελίδας",
