@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "Detaloj",
     "Delete" : "Forigi",
     "Saved" : "Konservita",
+    "Date added" : "Aldonita je",
+    "Link" : "Ligilo",
     "Tags" : "Etikedoj",
     "Description" : "Priskribo",
     "No bookmarks here." : "Neniu legosigno ĉi tie.",
@@ -21,6 +23,8 @@ OC.L10N.register(
     "Add to {instanceName} " : "Aldoni al {instanceName}",
     "Recently added" : "Lastaj aldonoj",
     "Most visited" : "Plej vizititaj",
+    "View mode" : "Vida reĝimo",
+    "List view" : "Lista vido",
     "RSS Feed" : "RSS-fluo",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Porĉiame forigi ĉiujn legosignojn el via konto. Ne eblos malfari tion!",
     "Delete all bookmarks" : "Forigi ĉiujn legosignojn",
@@ -28,7 +32,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Eraro dum la konservado de la legosigno",
     "Error" : "Eraro",
     "Uncategorized" : "Senkategoria",
+    "Error parsing the import result" : "Eraro dum analizo de la import-rezulto",
     "Import completed successfully." : "Enporto okazis sukcese",
+    "Do you really want to delete all your bookmarks?" : "Ĉu vi ja volas forigi ĉiujn viaj legosignoj?",
     "Set tags" : "Skribu etikedojn",
     "A Bookmark manager for Nextcloud" : "Mastrumilo de legosignoj por Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Tiu aplikaĵo ebligas konservi kaj organizi viajn preferitajn retejojn samloke, kaj samtempe sinkronigi ilin kun viaj diversaj aparatoj kaj retumiloj.\nVidu tie programaron de ekstera liveranto: https://github.com/nextcloud/bookmarks#third-party-clients",
