@@ -23,6 +23,8 @@ OC.L10N.register(
     "Add to {instanceName} " : "Añadir a {instanceName}",
     "Recently added" : "Añadido recientemente",
     "Most visited" : "Más visitado",
+    "View mode" : "Modo de visualización",
+    "List view" : "Vista de lista",
     "RSS Feed" : "Fuente RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Eliminar permanentemente todos los marcadores de tu cuenta. ¡No hay vuelta atrás!",
     "Delete all bookmarks" : "Eliminar todos los marcadores",
