@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "Tiedot",
     "Delete" : "Poista",
     "Saved" : "Tallennettu",
+    "Date added" : "Lisäyspäivä",
+    "Link" : "Linkki",
     "Tags" : "Tunnisteet",
     "Description" : "Kuvaus",
     "No bookmarks here." : "Täällä ei ole kirjanmerkkejä.",
@@ -19,6 +21,8 @@ OC.L10N.register(
     "Settings" : "Asetukset",
     "Recently added" : "Äskettäin lisätty",
     "Most visited" : "Vierailuimmat",
+    "View mode" : "Näkymätila",
+    "List view" : "Luettelonäkymä",
     "RSS Feed" : "RSS-syöte",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Poista kaikki tililläsi olevat kirjanmerkit pysyvästi. Tätä toimintoa ei voi perua!",
     "Delete all bookmarks" : "Poista kaikki kirjanmerkit",
