@@ -2,9 +2,9 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "Favoris",
-    "Failed to import one bookmark, because: " : "Impossible d'importer un favori",
+    "Failed to import one bookmark, because: " : "Échec lors de l\\'importation d'un favori. Raison: ",
     "No file provided for import" : "Aucun fichier à importer.",
-    "Unsupported file type for import" : "Type de fichier non supporté",
+    "Unsupported file type for import" : "Type de fichier non pris en charge",
     "Add a Bookmark" : "Ajouter un favori",
     "Add folder" : "Ajouter un dossier",
     "Select" : "Sélectionner",
@@ -23,6 +23,8 @@ OC.L10N.register(
     "Add to {instanceName} " : "Ajouter à {instanceName}",
     "Recently added" : "Ajoutés récemment",
     "Most visited" : "Les plus visités",
+    "View mode" : "Mode d'affichage",
+    "List view" : "Affichage liste",
     "RSS Feed" : "Flux RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Supprimer de manière définitive tous les favoris de votre compte. Il n'y a aucun moyen de revenir en arrière !",
     "Delete all bookmarks" : "Supprimer tous les favoris",
