@@ -28,8 +28,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Hiba történt a könyvjelző mentése közben.",
     "Error" : "Hiba",
     "Uncategorized" : "Kategorizálatlan",
-    "Import error" : "Importálási hiba",
+    "Error parsing the import result" : "Import eredmény feldolgozási hiba",
     "Import completed successfully." : "Sikeres importálás.",
+    "Do you really want to delete all your bookmarks?" : "Biztosan törölni akarod az összes könyvjelződet?",
     "Set tags" : "Cimke beállítás",
     "A Bookmark manager for Nextcloud" : "Könyvjelző kezelő Nextcloud-hoz",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Ez az alkalmazás lehetővé teszi, hogy kedvenc helyeit egy központi helyen tárolja és rendezze, miközben biztosítja a különböző eszközökkel és böngészőkkel való szinkronizálást.\n\nNézze meg a harmadik féltől származó klienseket: https://github.com/nextcloud/bookmarks#third-party-clients",
