@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "Nánar",
     "Delete" : "Eyða",
     "Saved" : "Vistað",
+    "Date added" : "Bætt við dags",
+    "Link" : "Tengill",
     "Tags" : "Merki",
     "Description" : "Lýsing",
     "No bookmarks here." : "Engin bókamerki hér.",
@@ -21,6 +23,8 @@ OC.L10N.register(
     "Add to {instanceName} " : "Bæta við {instanceName} ",
     "Recently added" : "Nýlega bætt við",
     "Most visited" : "Mest heimsótt",
+    "View mode" : "Skoðunarhamur",
+    "List view" : "Listasýn",
     "RSS Feed" : "RSS streymi",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Eyddu varanlega öllum bókamerkjum úr aðgangnum þínum. Ekki er hægt að afturkalla þetta!",
     "Delete all bookmarks" : "Eyða öllum bókamerkjum",
@@ -28,7 +32,9 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Villa kom upp við að reyna að vista bókamerkið.",
     "Error" : "Villa",
     "Uncategorized" : "Óflokkað",
+    "Error parsing the import result" : "Villa við að þátta niðurstöður innflutnings",
     "Import completed successfully." : "Tókst að flytja inn.",
+    "Do you really want to delete all your bookmarks?" : "Viltu í alvörunni eyða öllum bókmerkjunum þínum?",
     "Set tags" : "Stilla merki",
     "A Bookmark manager for Nextcloud" : "Bókamerkjastjóri fyrir Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Þetta forrit gerir þér kleift að geyma og skipuleggja slóðir á uppáhaldsvefsíðurnar þínar , allt á einum stað, um leið og hægt er að samstilla þetta við hin ýmsu tæki og vafra sem þú notar.\nSkoðaðu forrit frá utanaðkomandi aðilum hér: https://github.com/nextcloud/bookmarks#third-party-clients",
