@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "詳細",
     "Delete" : "削除",
     "Saved" : "保存しました",
+    "Date added" : "追加日",
+    "Link" : "リンク",
     "Tags" : "タグ",
     "Description" : "説明",
     "No bookmarks here." : "ブックマークがありません。",
@@ -21,6 +23,8 @@ OC.L10N.register(
     "Add to {instanceName} " : "{instanceName}に追加",
     "Recently added" : "最近追加",
     "Most visited" : "最も訪れた",
+    "View mode" : "表示モード",
+    "List view" : "リスト表示",
     "RSS Feed" : "RSS フィード",
     "Permanently remove all bookmarks from your account. There is no going back!" : "アカウントからすべてのブックマークを完全に削除します。 戻ることはありません！",
     "Delete all bookmarks" : "すべてのブックマークを削除",
