@@ -12,6 +12,8 @@ OC.L10N.register(
     "Details" : "Детаљи",
     "Delete" : "Обриши",
     "Saved" : "Сачувано",
+    "Date added" : "Датум додавања",
+    "Link" : "Веза",
     "Tags" : "Ознаке",
     "Description" : "Опис",
     "No bookmarks here." : "Овде нема забелешки",
@@ -21,6 +23,8 @@ OC.L10N.register(
     "Add to {instanceName} " : "Додај на {instanceName} ",
     "Recently added" : "Недавно додате",
     "Most visited" : "Најпосећеније",
+    "View mode" : "Режим приказа",
+    "List view" : "Приказ листе",
     "RSS Feed" : "RSS довод",
     "Permanently remove all bookmarks from your account. There is no going back!" : "Трајно брише све забелешке са налога. Нема назад!",
     "Delete all bookmarks" : "Обриши све забелешке",
